/**
******************************************************************************
* @file    IRPyro_API_multi_device_layer.h
* @author  _KEMET Ltd.
* @date    March 2018
* @version Release 1.0.6
* @copyright (c) 2018 _KEMET, Ltd
* @brief   IRPyro data structures and prototype functions
* @verbatim
 ===============================================================================
                      ##### How to use this driver #####
 ===============================================================================
      [..]
       (#) Make sure that IRPyro_LIST_SIZE is big enough for your list
       (#) Declare an IRPyro_list_type variable in your code
       (#) Declare as many IRPyro_sensor_device_type variables as IRPyros sensors
           on the list.
       (#) Fill the values for CS, INT and address for each IRPyro
       (#) Fill the values for number_of_active_channels and read_mode
       (#) AFE, CCP and WUP can be left empty if desired, configuration macros
           will fill them with default values
       (#) Call IRPyro_open() to commit the values to the physical IRPyro
       (#) IRPyro_read() retrieves the values sampled by the IRPyro sensor
       (#) Modify the IRPyro settings using IRPyro_IOCTL()
       (#) Close the device when finished using IRPyro_read()
      [..]
   @endverbatim
******************************************************************************
   @attention <h2><center>&copy; COPYRIGHT 2018 _KEMET, Ltd</center></h2>
   @verbatim
    Copyright (c) 2018, _KEMET, Ltd
    All rights reserved.

    THIS SOFTWARE IS PROVIDED BY _KEMET, Ltd ''AS IS'' AND ANY
    EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
    DISCLAIMED. IN NO EVENT SHALL _KEMET, Ltd BE LIABLE FOR ANY
    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
    (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
    ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
   @endverbatim
******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef IRPyro_API_multi_device_layer
#define IRPyro_API_multi_device_layer

/* Includes ------------------------------------------------------------------*/
#include "IRPyro_API_single_device_layer.h"

/** @defgroup IRPyro_LIST_ctes Constants to access IRPyro multi device layer
  * @ingroup IRPyro_multi
  * @brief Defines the size of a LIST
  * @{
  */
/* Exported constants ------------------------------------------------------------*/
#define IRPyro_LIST_SIZE               4  // IRPyros in a LIST
/** end of group IRPyro_LIST_ctes
  * @}
  */
/** @defgroup IRPyro_LIST_structs Structures to access the multi device layer of IRPyro
  * @ingroup IRPyro_multi
  * @brief An IRPyro LIST is an array of pointers to an IRPyro_device_type variable
  * @{
  */
/* Exported types ------------------------------------------------------------*/
/**
  * @struct IRPyro_devices IRPyro_API_multi_device_layer.h
  * @brief  IRPyro group definition
  */
typedef IRPyro_sensor_device_type IRPyro_devices[IRPyro_LIST_SIZE];          ///< pointers to pre-allocated IRPyro sensors
// struct IRPyro_sensor_device
//IRPyro_sensor_device_type

/** end of group IRPyro_LIST_structs
  * @}
  */
/* Exported functions ------------------------------------------------------- */
uint8_t IRPyro_open_devices(IRPyro_devices this_list, uint8_t list_size);
uint8_t IRPyro_read_devices(IRPyro_devices this_list, uint8_t list_size);
uint8_t IRPyro_close_devices(IRPyro_devices this_list, uint8_t list_size);
uint8_t IRPyro_ioctl_devices(IRPyro_devices this_list, uint8_t list_size, IRPyro_cmd_type* cmd, IRPyro_arg_type arg);
//------------------------------------------------------------------------------//
#endif
/* ********** Copyright (c) 2018 _KEMET, Ltd. **********END OF FILE************/
