/**
******************************************************************************
* @file    message_pack.c
* @author  _KEMET, Ltd
* @date    March 2018
* @version Release 1.0.6
* @copyright (c) 2018 _KEMET, Ltd
* @brief Sensor data/configuration is packaged to be send to the GUI
*
* @verbatim
 ===============================================================================
                      ##### Description #####
 ===============================================================================
  [..]
  [..]
 @endverbatim
  ******************************************************************************
   @attention <h2><center>&copy; COPYRIGHT 2018 _KEMET, Ltd</center></h2>
   @verbatim
    Copyright (c) 2018, _KEMET, Ltd
    All rights reserved.

    THIS SOFTWARE IS PROVIDED BY _KEMET, Ltd ''AS IS'' AND ANY
    EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
    DISCLAIMED. IN NO EVENT SHALL _KEMET, Ltd BE LIABLE FOR ANY
    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
    (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
    ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
   @endverbatim

  ******************************************************************************
  */
/* Includes ------------------------------------------------------------------*/
#ifndef MESSAGE_PACK
#include "message_pack.h"
#endif
extern uint8_t EmitterStatus ;                   // capture
extern uint8_t isStreaming;                      // capture
extern uint8_t status_need_to_send;
extern uint8_t mode_sleeping ;                   // capture
extern uint8_t mode_lowPower ;                   // capture
/** @defgroup message_pack Message Pack
  * @ingroup Message_Handler
  * @brief Packs a message to the GUI with the adequate frame
  * @verbatim
  *
  * @endverbatim
  * @note
  * @{
  */
/**
* @brief Puts a byte array into a designated message queue
*/
static void message_pack_block_send(uint8_t const *data, uint16_t size)
{
    do
    {
        message_putchar(*data, 0);
        ++ data;
        -- size;
    }
    while (size); //  && (USB_SENT == op_result)
    message_putchar(0, 1);
}
/**
* @brief Packs collected data for the active channels into the firmware
*/
extern int32_t ConfiguredSensorsSamplingDataToGUI[8];
void message_pack_stream_send(void)
{
    uint8_t data[32] ;

    data[0] = 0xFF ;          // header
    data[1] = 0xFF ;          // header
    data[2] = 0xFF ;          // header
    data[3] = 0xFF ;          // header
    for(uint8_t i=0 ; i< 7; i++)
    {
        data[4 + i*3] = (uint8_t) (ConfiguredSensorsSamplingDataToGUI[i] >> 16) ;  // msb
        data[5 + i*3] = (uint8_t) (ConfiguredSensorsSamplingDataToGUI[i] >> 8) ;
        data[6 + i*3] = (uint8_t) ConfiguredSensorsSamplingDataToGUI[i] ;    // lsb
    }
    data[25] = (uint8_t) (ConfiguredSensorsSamplingDataToGUI[7] >> 8) ;  // frame count 1
    data[26] = (uint8_t) ConfiguredSensorsSamplingDataToGUI[7] ;    // frame count 0
    /* This code reports the current state of the emitter if any.
     If we are using an external emitter (not controlled by our hardware) we report the state of the
     pin which has been configured to receive an external state bit (pin 0 of port B).
     If we are using an internal emitter we report our internal flag corresponding to whether it is
     currently on or off.
     If we are not using an emitter the 'emitter on' bit is set to 0 */

    switch ( EmitterStatus & 3 )
    {
    case 0 :
        // no emitter in use
        data[27] = 0 ;
        break ;
    case 1 :
        // external emitter in use
        data[27] = ( 1 == GPIO_ReadInputDataBit(GPIOB,1) ) ? 1 : 0 ;
        break ;
    default :
        // internal emitter in use
        data[27] = ( 4 == ( EmitterStatus & 4) ) ? 1 : 0 ;
        break ;
    }
    data[28] = 0xFF ;         // footer
    data[29] = 0xFF ;         // footer
    data[30] = 0xFF ;         // footer
    data[31] = 0xFE ;         // footer
    static uint8_t led_ready_value = 0;
    led_ready_value = (!led_ready_value) & 1;
    LED_READY(led_ready_value);

    message_pack_block_send(data, 32) ;        // send data
    led_ready_value = (!led_ready_value) & 1;
    LED_READY(led_ready_value);

}
/**
* @brief Packs firmware status for the GUI: Streaming and power mode
*/
void message_pack_status_send(void)
{
    uint8_t data[32]= {0};

    data[0] = 0xFF ;          // header
    data[1] = 0xFF ;          // header
    data[2] = 0xFF ;          // header
    data[3] = 0xFF ;          // header

    data[4] = 0x01 ;
    data[5] = isStreaming ;   // streaming mode
    if ( mode_sleeping > 0 )
    {
        data[6] = 0x00 ;      // mode normal
        data[7] = 0x01 ;      // mode sleep
    }
    else
    {
        data[6] = 0x01 ;      // mode normal
        data[7] = 0x00 ;      // mode sleep
    }
    data[8] = mode_lowPower ; // mode low power
    data[28] = 0xFF ;          // footer
    data[29] = 0xFF ;          // footer
    data[30] = 0xFF ;          // footer
    data[31] = 0xFD ;          // footer

    message_pack_block_send(data, 32) ;         // send data
    status_need_to_send = 0;
}
/**
* @brief selects the correct function to send data to the gui.
*/
void get_bytes_to_GUI(uint8_t packet_function, uint8_t const *bytes_to_gui, uint16_t size)
{
    switch (packet_function)
    {
    case 1:
        message_pack_status_send();
        break;
    case 2:
        message_pack_stream_send();
        break;
    case 3:
        message_pack_block_send(bytes_to_gui, size);
        break;
    default:
        break;
    }
}
/** end of message_pack group
  * @}
  */
/* ********** Copyright (c) 2018 _KEMET, Ltd. **********END OF FILE************/

