/**
******************************************************************************
* @file    main_IRPyro_microcontroller_only_demo.c
* @author  _KEMET, Ltd
* @date    March 2018
* @version Release 1.0.0
* @copyright (c) 2018 _KEMET, Ltd
* @brief   Examples of single sensor and multiple sensor streaming. Also IOCTL
*          of a single sensor.
*
* @verbatim
 ===============================================================================
                      ##### How to use this example #####
 ===============================================================================
  [..]
  Requirements
   (#) Keil compiler version 5 onwards (https://www.keil.com/download/product/)
       to build this example.
   (#) C99 option enabled on the compiler to support initialization macros.
   (#) The STM32 Standard Peripheral Library, see:
      (http://www.st.com/content/st_com/en/products/embedded-software/mcus-embedded-software/stm32-embedded-software/stm32-standard-peripheral-libraries.html)
  [..]
   (#) See Micro_controller_template.c for details on how to configure SDA,SCL
       INT and CS lines values.
   (#) Compile, load and run.
   (#) Display collected data on RealTerm or equivalent
 @endverbatim
  ******************************************************************************
   @attention <h2><center>&copy; COPYRIGHT 2018 _KEMET, Ltd</center></h2>
   @verbatim
    Copyright (c) 2018, _KEMET, Ltd
    All rights reserved.

    THIS SOFTWARE IS PROVIDED BY _KEMET, Ltd ''AS IS'' AND ANY
    EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
    DISCLAIMED. IN NO EVENT SHALL _KEMET, Ltd BE LIABLE FOR ANY
    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
    (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
    ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
   @endverbatim

  ******************************************************************************
  */
/* Includes ------------------------------------------------------------------*/
#include "main_IRPyro_microcontroller_only_demo.h"

static void Configure_MCU(void);
static void demo_board_sensor_control(int value);
static void usart_callback_setup(void);

/** @defgroup IRPyroAPI_micro_controller_only Bare bones micro controller firmware
  * @brief Support micro controller functions without the API component
  * @{
  */
/**
  * @brief Call point to the example functions
  */
int main(void)
{
    Configure_MCU();
}
/**
  * @brief Example to initialize the STM32F303K8 micro controller
  * @attention Set your serial terminal console with the following parameters:
  * @verbatim
  *        Baud Rate:           921600
  *        Parity:                None
  *        Data Bits:                8
  *        Stop Bits:                1
  *        Hardware Flow Control: None
  *        Software Flow Control: None
  * @endverbatim
  * @note  Modify accordingly depending on architecture
  */
static void Configure_MCU(void)
{
    /*-------------------------- board setup ---------------------------------*/
    Micro_controller_template_init();
    usart_callback_setup();
    // disable all CS lines
    demo_board_sensor_control(0);
    /*----------------- enable the sensor for streaming-----------------------*/
    while(1)
    {
        UART_PutString(USART2, (uint8_t*)"MCU configured and ready!\n");
    }
}

/**
 * @brief USART TX function
 */
static void tx_function(void)
{

}
/**
 * @brief USART RX function
 */
static void rx_function(void)
{
    uint8_t uart_byte = (uint8_t)USART_ReceiveData(USART2);
}
/**
 * @brief configures USART irq functions
 */
static void usart_callback_setup(void)
{
    USART_Callback_Rx_Setup(rx_function);
    USART_Callback_Tx_Setup(tx_function);
}
/**
 * @brief Changes the state of all the CS lines as used on the IRPyro backplane board
 * @param state   0 disabled / 1 enabled
 */
void demo_board_sensor_control(int state)
{
    CS_pin_set(2,1,state);
    CS_pin_set(2,3,state);
    CS_pin_set(2,4,state);
    CS_pin_set(2,5,state);
}
/** end of IRPyroAPI_micro_controller_only
  * @}
  */
/* ********** Copyright (c) 2018 _KEMET, Ltd. **********END OF FILE************/
